% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods-markers.R
\name{retrieveGenesInfo,scRNAseq-method}
\alias{retrieveGenesInfo,scRNAseq-method}
\alias{retrieveGenesInfo}
\title{retrieveGenesInfo}
\usage{
retrieveGenesInfo(theObject, groupBy="clusters",
                orderGenes="initial", getUniprot=TRUE, cores=2,
                saveInfos=FALSE)
}
\arguments{
\item{theObject}{An Object of class scRNASeq for which the count matrix was
normalized (see ?normaliseCountMatrix), tSNE were calculated (see
?generateTSNECoordinates), dbScan was run (see ?runDBSCAN), cells were
clustered (see ?clusterCellsInternal), as clusters themselves (see
?calculateClustersSimilarity), and ?rankGenes as ?retrieveTopMarkers.}

\item{groupBy}{A column in the input table used for grouping the genes in
the output tables. This option is useful if a table contains genes from
different clusters. Default = "clusters".}

\item{orderGenes}{If "initial" then the order of genes will not be changed.
The other option is "alphabetical". Default = "initial".}

\item{getUniprot}{Boolean, whether to get information from UniProt or not.
Default = TRUE.}

\item{cores}{Maximum number of jobs that CONCLUS can run in parallel.
Default is 1.}

\item{saveInfos}{If TRUE, save the genes infos table in the directory
defined in theObject (?getOutputDirectory), in the sub-directory
'marker_genes/saveGenesInfo'.}
}
\value{
Display a table with the info retrieved.
}
\description{
This method retrieve information about the marker genes of each cluster
querying the Ensembl database with biomaRt and display the result.
}
\details{
The output dataframe is composed of the following columns:

- uniprot_gn_symbol: Uniprot gene symbol. \cr
- clusters: The cluster to which the gene is associated. \cr
- external_gene_name: The complete gene name. \cr
- go_id: Gene Ontology (GO) identification number. \cr
- mgi_description: If the species is mouse, description of the gene
on MGI. \cr
- entrezgene_description: Description of the gene by Entrez database. \cr
- gene_biotype: protein coding gene, lincRNA gene, miRNA gene, unclassified
non-coding RNA gene, or pseudogene. \cr
- chromosome_name: The chromosome on which the gene is located. \cr
- Symbol: Official gene symbol. \cr
- ensembl_gene_id: ID of the gene on the ensembl database. \cr
- mgi_id: If the species is mouse, ID of the gene on the MGI database. \cr
- entrezgene_id: ID of the gene on the entrez database. \cr
- uniprot_gn_id: ID of the gene on the uniprot database. \cr
}
\examples{
## Object scr containing the results of previous steps
load(system.file("extdata/scrFull.Rdat", package="conclus"))

## Getting genes info
scr <- retrieveGenesInfo(scr, cores=2)

}
\seealso{
rankGenes retrieveTopClustersMarkers
}
\author{
Ilyess RACHEDI, based on code by Polina PAVLOVICH and Nicolas DESCOSTES.
}
